/*
 *  Copyright 2013 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

/**
 * This factory creates Ametys.message.MessageTarget for a cart.
 * See #createTargets for more details.
 * @private
 */
Ext.define('Ametys.plugins.cart.CartMessageTargetFactory', {
	extend: 'Ametys.message.factory.DefaultMessageTargetFactory',
		
	/**
	 * Create the targets for a message
	 * @param {Object} parameters The parameters needed by the factory to create the message. Can not be null. Handled elements are
	 * @param {String[]} parameters.ids The cart's identifiers.
	 * @param {Function} callback The callback function called when the targets are created. Parameters are
	 * @param {Ametys.message.MessageTarget[]} callback.targets The targets created. Cannot be null.
	 */
	createTargets: function(parameters, callback)
	{
		var ids = parameters.ids || (parameters.id ? [parameters.id] : []);
		Ametys.plugins.cart.CartsDAO.getCarts(ids, Ext.bind(this._createTargets, this, [callback], 1));
	},

	/**
	 * Create the carts targets
	 * @param {Ametys.plugins.cart.Cart[]} carts Array of carts.
	 * @param {Function} callback The callback function called when the targets are created. Parameters are
	 * @param {Ametys.message.MessageTarget[]} callback.targets The targets created. Cannot be null.
	 * @private
	 */
	_createTargets: function (carts, callback)
	{
		var targets = [];
		
		Ext.Array.forEach(carts, function(cart) {
			targets.push(Ext.create('Ametys.message.MessageTarget', {
				type: this.getType(),
				parameters: cart.getProperties()
			}));	
		}, this);
			
		callback(targets);
	}
});

